# Macron.pl
# Macron v1.3.2 plugin for Movable Type
# http://www.chipple.net/mt/macronplugin/
# by Patrick Benny http://www.chipple.net/
# This code cannot be redistributed without permission from the author. 
#
# Version history
#   1.3.2 - 2008/3/27  - Now supports Movable Type 4.1
#   1.3.1 - 2007/8/31  - Working version for MT4
#   1.3   - 2007/8/6   - Now supports Movable Type 4
#   1.2   - 2006/7/6   - Added support for Movable Type 3.3
#   1.1   - 2006/2/3   - Added "Set above as [entry's author]" button
#   1.0   - 2005/11/16 - First release


use strict;
package MT::Plugin::Macron;

use vars qw( $VERSION );
$VERSION = '1.3.2';

require MT::Plugin;
require MT;

my $plugin = MT::Plugin->new({
	name => "Macron",
	description => 'Adds a macron button to the entry editing screen.',
	doc_link => 'http://www.chipple.net/mt/macronplugin/',
	author_name => 'Patrick Benny',
	author_link => 'http://www.chipple.net/',
	version => $VERSION,
});
MT->add_plugin($plugin);

## For Movable Type 4.1
MT->add_callback('MT::App::CMS::template_source.archetype_editor', 9, $plugin, \&_template_mt4);
## For Movable Type 4.0
MT->add_callback('MT::App::CMS::template_source.edit_entry', 9, $plugin, \&_template_mt4);

## For Movable Type 3.3+
MT->add_callback('MT::App::CMS::AppTemplateSource.edit_entry', 9, $plugin, \&_template_mt3);
MT->add_callback('MT::App::CMS::AppTemplateSource.bm_entry', 9, $plugin, \&_template_mt3);
## For Movable Type 3.2
MT->add_callback('bigpapi::template::edit_entry', 9, $plugin, \&_template_mt3);
MT->add_callback('bigpapi::template::bm_entry', 9, $plugin, \&_template_mt3);


# For Movable Type 4
sub _template_mt4 {

  my ($cb, $app, $template) = @_;

  $$template =~ s%(class="command-underline toolbar button"><b>U</b><s></s></a>)%$1
<style type="text/css">
.editor-toolbar a.button.command-macron {
    background-image: url(<\$mt:var name="static_uri"\$>images/buttons/toolbar/macron.png);
    background-position: 0 0;
}
.editor-toolbar a.button.command-macron:active {
    background-position: -22px 0;
}
.editor-toolbar a.button.command-macron:hover {
    background-position: -44px 0;
}
</style>
<script type="text/javascript">

function __getKeyEventCommand_macron( event ) {
    if( (event.metaKey || event.ctrlKey) && \!event.shiftKey && \!event.altKey ) {
        var c = ( String.fromCharCode( event.charCode || event.keyCode ) || "" ).toUpperCase();
        switch( c ) {
            case "M": return "macron";
        }
    }
    
    return this.__getKeyEventCommand_preMacron();
}

function __execCommand_macron( command, userInterface, argument ) {
    var text = this.getSelectedText();
    if ( \!defined( text ) )
        text = '';
    switch ( command ) {
        case "macron":
            this.setSelection( text + String.fromCharCode(0x304) );
            this.editor.setChanged();
            return;
            break;
    }
    this.__execCommand_preMacron();
}

function initMacron () {
  if (app && app.editor && app.editor.textarea) {
    app.editor.__getKeyEventCommand_preMacron = app.editor.getKeyEventCommand;
    app.editor.getKeyEventCommand = __getKeyEventCommand_macron;
    app.editor.textarea.__execCommand_preMacron = app.editor.textarea.execCommand;
    app.editor.textarea.execCommand = __execCommand_macron;
  }
}
// Doesn't work
//DOM.addEventListening(window, "load", initMacron);

// Alternate

function execMacron() {
    var ta = app.editor.textarea;
    var text = ta.getSelectedText();
    if ( \!defined( text ) )
        text = '';
    ta.setSelection( text + String.fromCharCode(0x304) );
    ta.editor.setChanged();
}

</script>
                                <a href="javascript: void 0;" title="<__trans phrase="Macron" escape="html">" class="command-macron toolbar button" onclick="execMacron();return false;"><b>Macron</b><s></s></a>%g;

}

# For Movable Type 3.2, 3.3+
sub _template_mt3 {

  my ($cb, $app, $template) = @_;

  $$template =~ s|(
if \(canFormat\) {)|
function insertMacron (e) {
  if (!canFormat) return;
  var str = getSelected(e);
  if (str.length != 1) return;
  setSelection(e, str + String.fromCharCode(0x304));
  return false;
}$1|;

  # For Movable Type 3.3+ edit_entry
  $$template =~ s|(
        write\('<img title="<MT_TRANS phrase="Insert Link">" onclick="return insertLink\(document.entry_form.text(_more)?\)")|
        write('<img title="<MT_TRANS phrase="Macron">" onclick="return insertMacron(document.entry_form.text$2)" src="<TMPL_VAR NAME=STATIC_URI>images/formatting-icons/macron.gif" alt="Macron" width="26" height="19" />');
$1|g;

  # For Movable Type 3.2, and also Movable Type 3.3 bm_entry
  $$template =~ s|(
        write\('<a title="<MT_TRANS phrase="Insert Link">" href="#" onclick="return insertLink\(document.entry_form.text(_more)?\)">)|
        write('<a title="<MT_TRANS phrase="Macron">" href="javascript:void(0);" onclick="return insertMacron(document.entry_form.text$2)"><img src="<TMPL_VAR NAME=STATIC_URI>images/html-macron.gif" alt="Macron" width="22" height="16" /></a>');
$1|g;

}

1;